# Generated by roxygen2: do not edit by hand

export(mf_annotation)
export(mf_arrow)
export(mf_background)
export(mf_base)
export(mf_choro)
export(mf_credits)
export(mf_distr)
export(mf_export)
export(mf_frame)
export(mf_get_borders)
export(mf_get_breaks)
export(mf_get_leg_pos)
export(mf_get_links)
export(mf_get_mtq)
export(mf_get_pal)
export(mf_get_pencil)
export(mf_get_ratio)
export(mf_grad)
export(mf_graticule)
export(mf_init)
export(mf_inset_off)
export(mf_inset_on)
export(mf_label)
export(mf_layout)
export(mf_legend)
export(mf_logo)
export(mf_map)
export(mf_png)
export(mf_prop)
export(mf_prop_choro)
export(mf_prop_typo)
export(mf_raster)
export(mf_scale)
export(mf_shadow)
export(mf_svg)
export(mf_symb)
export(mf_symb_choro)
export(mf_text)
export(mf_theme)
export(mf_title)
export(mf_typo)
export(mf_worldmap)
importFrom(classInt,classIntervals)
importFrom(grDevices,
  col2rgb,
  colorRampPalette,
  dev.list,
  dev.size,
  hcl.colors,
  hcl.pals,
  png,
  recordGraphics,
  rgb,
  svg,
  xy.coords
)
importFrom(graphics,
  arrows,
  axis,
  box,
  boxplot,
  grconvertX,
  grconvertY,
  hist,
  lines,
  locator,
  par,
  plot.new,
  plot.window,
  points,
  polygon,
  rasterImage,
  rect,
  segments,
  strheight,
  strwidth,
  symbols,
  text,
  title,
  xinch,
  xyinch,
  yinch
)
importFrom(maplegend,
  leg,
  leg_comp,
  leg_draw
)
importFrom(s2,
  as_s2_geography,
  s2_buffer_cells,
  s2_data_countries,
  s2_difference,
  s2_intersection,
  s2_union_agg
)
importFrom(sf,
  "st_crs<-",
  "st_geometry<-",
  st_agr,
  st_area,
  st_as_sf,
  st_as_sfc,
  st_bbox,
  st_buffer,
  st_cast,
  st_centroid,
  st_collection_extract,
  st_combine,
  st_convex_hull,
  st_coordinates,
  st_crs,
  st_geometry,
  st_geometry_type,
  st_graticule,
  st_intersection,
  st_intersects,
  st_is_empty,
  st_is_longlat,
  st_make_grid,
  st_multilinestring,
  st_multipolygon,
  st_polygon,
  st_read,
  st_sample,
  st_set_agr,
  st_set_crs,
  st_set_geometry,
  st_sf,
  st_sfc,
  st_transform,
  st_union
)
importFrom(stats,
  aggregate,
  bw.SJ,
  density,
  median,
  na.omit,
  quantile,
  runif,
  sd
)
importFrom(utils,globalVariables)
