expect_silent(mf_get_borders(mtq))
expect_error(mf_get_borders(st_transform(mtq, "EPSG:4326")))
expect_error(mf_get_borders(mtq_p))
x <- mf_get_borders(mtq)
expect_equal(nrow(x), 142)
expect_inherits(sf::st_geometry(x), "sfc_MULTILINESTRING")
