mf_map(mtq)
expect_silent(mf_map(mtq_l, var = "fij", type = "grad"))
expect_silent(mf_map(mtq_l, var = "fij", type = "grad", add = FALSE))
expect_silent(mf_map(mtq, var = "POP", type = "grad", add = FALSE))
expect_error(mf_map(mtq_l, var = "fij", type = "grad", lwd = c(1, 2)))
expect_error(mf_map(mtq, var = "POP", type = "grad", cex = c(1, 2)))
