set.seed(46)
x <- runif(1000)
bks <- mf_get_breaks(x, nbreaks = 5, breaks = "equal")
r <- mf_distr(x)
expect_equal(r$bw, target = 0.04413086, tolerance = 1e-7)
expect_equal(r$nbins, target = 11)
expect_silent(mf_distr(x, nbins = 11))
expect_silent(mf_distr(x, nbins = 11, bw = .1))
expect_silent(mf_distr(x))
expect_silent(mf_distr(x, bw = .1))
expect_silent(mf_distr(x, nbins = 1000))
expect_silent(mf_distr(x, nbins = 2))
expect_silent(mf_distr(x = x, breaks = bks, pal = "Reds 2"))
expect_silent(mf_distr(x, yaxt = FALSE))
